from functools import wraps
from flask import request, jsonify
from werkzeug.exceptions import Unauthorized

from flaschengeist import logger


def login_required(**kwargs):
    from .controller.accessTokenController import AccessTokenController
    ac_controller = AccessTokenController()
    roles = None
    if "roles" in kwargs:
        roles = kwargs["roles"]

    def real_decorator(func):
        @wraps(func)
        def wrapper(*args, **kwargs):
            token = request.headers.get('Token')
            logger.debug("token is {{ {} }}".format(token))
            access_token = ac_controller.validate_token(token, request.user_agent, roles)
            if access_token:
                kwargs['access_token'] = access_token
                logger.debug("token {{ {} }} is valid".format(token))
                return func(*args, **kwargs)
            else:
                logger.info("token {{ {} }} is not valid".format(token))
                raise Unauthorized
        return wrapper
    return real_decorator
